using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using NationalInstruments.VisaNS;

namespace scancard
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            //
            // Set the default scanner count = 10
            textBox1.Text = "10";
        }

        private void button2_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            int i;
            int j;
            int cnt;
            string s;
            string tt;
            string readstring;
            string[] datarow = { "", "", "", "", "", "", "", "", "", "" };
            double h;
            MessageBasedSession mbSession;

            // Make sure the scanner count value between the valid range : 2 ~ 2000 
            cnt = Convert.ToInt32(textBox1.Text);
            if (cnt < 2)
            {
                cnt = 2;
                textBox1.Text = "2";
            }
            if (cnt > 2000)
            {
                cnt = 2000;
                textBox1.Text = "2000";
            }

            // Clear the dataGridView preview reading data
            if (dataGridView1.RowCount > 1)
            {
                dataGridView1.Rows.Clear();
            }

            // 
            // Try use the NI VISA ResourceManager to find "USB0::0x164E::0x0DAD" devices
            //
            try
            {
                j = ResourceManager.GetLocalManager().FindResources("USB0::0x164E::0x0DAD::?*").Length;
            }
            catch (Exception ex)
            {
                System.Windows.Forms.MessageBox.Show(ex.Message, "M3500A scancard");
                return;
            }

            //
            // Assign the first M3500A device for the test device
            string[] resources = ResourceManager.GetLocalManager().FindResources("USB0::0x164E::0x0DAD::?*");
            s = resources[0];

            // Open the working device session
            mbSession = (MessageBasedSession)ResourceManager.GetLocalManager().Open(s);

            // Send the Reset and Clear command
            mbSession.Write("*RST");
            mbSession.Write("*CLS");
            
            //
            // Check the M3500A device plug-in the scanner card ?
            // scanner card plug-in the return value is "1"
            mbSession.Write("rout:stat?");
            readstring = mbSession.ReadString();
            if (readstring.CompareTo("1") != 0)
            {
                System.Windows.Forms.MessageBox.Show("Scanner card not found.", "M3500A scancard");
                return;
            }

            // Set the user assigned scanner count in textBox1 and the scan interval timer 0.01
            mbSession.Write("rout:scan:count " + textBox1.Text );
            mbSession.Write("rout:scan:timer 0.1");
            Thread.Sleep(200);

            // Set the all 10 channels measurement function -- VOLTage DC
            for (j = 1; j < 10; j++)
            {
                tt = j.ToString();
                readstring = "rout:scan:func " + tt + ",\"" + "VOLT:DC" + "\"";
                mbSession.Write(readstring);
                Thread.Sleep(50);
            }

            // Trig the scanner card begin to scan
            mbSession.Write("rout:scan");
            while (true)
            {
                Application.DoEvents();
                mbSession.Write("rout:scan:state?");
                Thread.Sleep(50);
                readstring = mbSession.ReadString();

                h = Convert.ToDouble(readstring);
                i = Convert.ToInt32(h);
                label1.Text = i.ToString();
                label1.Text = label1.Text +" / " + textBox1.Text ;

                // Check the scaned count
                if (i >= cnt)
                {
                    break;
                }
            }

            // Fetch the scaned data 
            mbSession.Write("fetch?");
            Thread.Sleep(50);
            readstring = mbSession.ReadString(33000);

            // Put the scaned data to the dataGridView
            j = 0;
            while (true)
            {
                for (i = 0; i < 10; i++)
                {
                    datarow[i] = "";
                }
                for (i = 0; i < 10; i++)
                {
                    if (j >= readstring.Length)
                        break;

                    tt = readstring.Substring(j, 15);
                    datarow[i] = tt;
                    j += 16;
                }
                dataGridView1.Rows.Add(datarow);
                if (j >= readstring.Length)
                    break;

            }

            // Set the M3500A to local mode and close the working device session
            mbSession.Write("system:local");
            mbSession.Dispose();
      
        }

    }
}